<?php
/**
* 2007-2017 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2017 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

class ProductController extends ProductControllerCore
{
    public function init()
    {
        FrontController::init();

        // Obtengo en groups los grupos del cliente visitante
        if ((int)$this->context->customer->id > 0) {
            $groups = Customer::getGroupsStatic((int)$this->context->customer->id);
        } else {
            $groups = array();
            $groups[] = Configuration::get('PS_GUEST_GROUP');
            $groups[] = Configuration::get('PS_UNIDENTIFIED_GROUP');
        }

        // Obtengo los grupos del producto en product_groups
        $sql = "SELECT groups FROM "._DB_PREFIX_.
            "productvisibletogroup WHERE id_product = ".
            (int)Tools::getValue('id_product');

        $result = DB::getInstance()->getRow($sql);
        if ($result) {
            $product_groups = unserialize($result['groups']);
        } else {
            $product_groups = array();
        }

        $visible_pvg = false;
        if (count($product_groups) > 0) {
            foreach ($product_groups as $value) {
                if (in_array($value, $groups)) {
                    $visible_pvg = true;
                    break;
                }
            }
        } else {
            $visible_pvg = true;
        }

        if ($id_product = (int)Tools::getValue('id_product')) {
            $this->product = new Product(
                $id_product,
                true,
                $this->context->language->id,
                $this->context->shop->id
            );
        }

        if (!Validate::isLoadedObject($this->product)) {
            header('HTTP/1.1 404 Not Found');
            header('Status: 404 Not Found');
            $this->errors[] = Tools::displayError('Product not found');
        } else {
            $this->canonicalRedirection();
            $aa = isset($this->context->customer) ? $this->context->customer->id : 0;
            if (!$this->product->isAssociatedToShop() || !$this->product->active) {
                if (Tools::getValue('adtoken') == Tools::getAdminToken('AdminProducts'.
                    (int)Tab::getIdFromClassName('AdminProducts').
                    (int)Tools::getValue('id_employee')) && $this->product->isAssociatedToShop()) {
                    // If the product is not active, it's the admin preview mode
                    $this->context->smarty->assign('adminActionDisplay', true);
                } else {
                    $this->context->smarty->assign('adminActionDisplay', false);
                    if ($this->product->id_product_redirected == $this->product->id) {
                        $this->product->redirect_type = '404';
                    }
                    
                    switch ($this->product->redirect_type) {
                        case '301':
                            header('HTTP/1.1 301 Moved Permanently');
                            $hemen = $this->context->link->getProductLink($this->product->id_product_redirected);
                            Tools::redirect($hemen);
                            break;
                        case '302':
                            header('HTTP/1.1 302 Moved Temporarily');
                            header('Cache-Control: no-cache');
                            $hemen = $this->context->link->getProductLink($this->product->id_product_redirected);
                            
                            break;
                        case '404':
                        default:
                            header('HTTP/1.1 404 Not Found');
                            header('Status: 404 Not Found');
                            $this->errors[] = Tools::displayError('This product is no longer available.');
                            break;
                    }
                }
            } elseif (!$this->product->checkAccess($aa) || !$visible_pvg) {
                // EL CONDICIONAL DE ARRIBA
                header('HTTP/1.1 403 Forbidden');
                header('Status: 403 Forbidden');
                $this->errors[] = Tools::displayError('You do not have access to this product.');
            } else {
                // Load category
                $id_category = false;
                $aa = isset($_SERVER['HTTP_REFERER']) && $_SERVER['HTTP_REFERER'];
                $bb = Tools::secureReferrer($_SERVER['HTTP_REFERER']);
                $cc = preg_match(
                    '~^.*(?<!\/content)\/([0-9]+)\-(.*[^\.])|(.*)id_(category|product)=([0-9]+)(.*)$~',
                    $_SERVER['HTTP_REFERER'],
                    $regs
                );
                if ($aa == $bb && $cc) {
                    $id_object = false;
                    if (isset($regs[1]) && is_numeric($regs[1])) {
                        $id_object = (int)$regs[1];
                    } elseif (isset($regs[5]) && is_numeric($regs[5])) {
                        $id_object = (int)$regs[5];
                    }

                    if ($id_object) {
                        $referers = array($_SERVER['HTTP_REFERER'],urldecode($_SERVER['HTTP_REFERER']));
                        $aa = isset($this->context->cookie->last_visited_category);
                        $bb = (int)$this->context->cookie->last_visited_category;
                        $cc = in_array($this->context->link->getProductLink($id_object), $referers);
                        if (in_array($this->context->link->getCategoryLink($id_object), $referers)) {
                            $id_category = (int)$id_object;
                        } elseif ($aa && $bb && $cc) {
                            $id_category = (int)$this->context->cookie->last_visited_category;
                        }
                    }
                }
                $bb = Category::inShopStatic($id_category, $this->context->shop);
                $cc = Product::idIsOnCategoryId(
                    (int)$this->product->id,
                    array('0' => array('id_category' => $id_category))
                );
                if (!$id_category || !$bb || !$cc) {
                    $id_category = (int)$this->product->id_category_default;
                }
                $this->category = new Category((int)$id_category, (int)$this->context->cookie->id_lang);
                $aa = isset($this->context->cookie);
                $bb = isset($this->category->id_category);
                $cc = Module::isInstalled('blockcategories') && Module::isEnabled('blockcategories');
                if ($aa && $bb && !($cc)) {
                    $this->context->cookie->last_visited_category = (int)$this->category->id_category;
                }
            }
        }
    }
}
